<?php 

class SLZ_Widget_Taxonomy extends WP_Widget {

	private $slz_widget;
	private $config;

	/**
	 * @internal
	 */
	function __construct() {

		$this->slz_widget = slz_ext('widgets')->get_widget( get_class ($this) );
		
		if ( is_null( $this->slz_widget ) ) {
			trigger_error('Cannot load this widget', E_USER_WARNING);
			return;
		}

		$this->config = $this->slz_widget->get_config('general');

		$widget_ops = array( 
			'description' => (!empty( $this->config['description'] ) ? $this->config['description'] : ''),
			'classname'   => (!empty( $this->config['classname'] ) ? $this->config['classname'] : ''),
		);
		parent::__construct( $this->config['id'], $this->config['name'], $widget_ops );
	}
	/**
	 * @param array $args
	 * @param array $instance
	 */
	function widget( $args, $instance ) {
		$defaults = array(
			'title'           => '',
			'limit'           => '',
			'show_post_count' => '',
			'taxonomy'        => '',
			'style'           => ''
		);
		$instance = array_merge( $defaults, (array) $instance );
		
		//get translated strings
		$title = slz_ext_widget_filters_widget_title( $args, $instance );
	
		$data = array(
			'before_widget'  => $args['before_widget'],
			'after_widget'   => $args['after_widget'],
			'title'          => $title,
			'show_count'     => esc_attr($instance['show_post_count']),
			'taxonomy'       => esc_attr($instance['taxonomy']),
			'limit'          => esc_attr($instance['limit']),
			'style'          => esc_attr($instance['style'])
		);

		echo slz_render_view($this->slz_widget->locate_path( '/views/front.php' ), $data );
		
	}

	function update( $new_instance, $old_instance ) {
		$new_instance['show_post_count'] = strip_tags($new_instance['show_post_count']);
		return $new_instance;
	}

	function form( $instance ) {
		$instance = wp_parse_args( (array) $instance,array( 
			'title'           => '',
			'limit'           => '5',
			'show_post_count' => '',
			'taxonomy'        => '',
			'style'           => ''
			));
		$arr_tax = $this->slz_widget->get_config('taxonomy');
		$arr_style = $this->slz_widget->get_config('style');
		$data = array(
			'data'        => $instance,
			'wp_widget'   => $this,
			'p_taxonomy'  => $arr_tax,
			'p_style'     => $arr_style,
		);

		echo slz_render_view($this->slz_widget->locate_path( '/views/admin.php' ), $data );
		
	}
}